import { Meta, Canvas, Source } from "@storybook/blocks";
import * as Stories from "./whitepaper.stories";

<Meta of={Stories} name="Docs" />

# Whitepaper

If there is only one download available, instead of rendering the donwloads items inside the
`ux-form-group` elements, render directly the one download, with the `ux-checkbox` possessing the
`checked` attribute.

<Canvas of={Stories.Step1} />

# Whitepaper Step 2

<Canvas of={Stories.Step2} />

# Form Success response

When the form is submitted asynchronously through the `ux-form` component to the url indicated in the
form `action` attribute (or throught the `async-url` attribute on the `ux-form` component), the `ux-form`
expects an html response that will replace the content of the `ux-form` completely.
The html response should be like the one in the code snippet of this story, in order for the template to
look like the below example.

<Canvas of={Stories.Success} />

# Detailed HTML Code for Form steps

Here is an overview of the code for the various for steps. <br />
It has been simplified by removing the actual form elements and download elements
content, showing only the first one of the group.

# HTML For First Step of the Form

This is the code for the first part of the form. <br />
The classes of some elements are different based on these settings: if a marginal column is
present and if the one column layout or two column layout is selected. <br />
Look at the comments in the HTML code that are above the element with changing classes
depending on the above mentioned variables. The different classes for these elements Depending
on the configuration are described in the following table:

<table style={{ width: "100%" }}>
    <thead>
        <tr>
            <th></th>
            <th>one column - no sidebar</th>
            <th>one column - with sidebar</th>
            <th>two columns - no sidebar</th>
            <th>two columns - with sidebar</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td class="ux-u-text-bold">ELEMENT1</td>
            <td>gr-8@large push-2@large gr-10@d push-1@d gr-12 no-gutter</td>
            <td>gr-12@large push-0@large gr-10@d push-1@d gr-12 no-gutter</td>
            <td>gr-12@large push-0@large gr-12@d push-0@d gr-12 no-gutter</td>
            <td>gr-12@large push-0@large gr-12@d push-0@d gr-12 no-gutter</td>
        </tr>
        <tr>
            <td class="ux-u-text-bold">ELEMENT2*</td>
            <td>gr-12 no-gutter</td>
            <td>gr-12 no-gutter</td>
            <td>gr-12 no-gutter gr-6@large</td>
            <td>gr-12 no-gutter gr-6@large</td>
        </tr>
    </tbody>
</table>

\*Please note, when the configuration of 2 columns is selected, There have to be 2
sibling elements corresponding to ELEMENT2, each containing half of the download
teaser elements. This is because the download teaser have the `read more` functionality
and have to be arranged in 2 separate columns.

**_ P.S _** in case there is only one download in the list, please remove all the attributes
from it's closest `ux-form-froup` element and set the `preselected` attribute to `true` on the
`ux-iws-selectable-download` as also documented in the relevant story.

<Source 
    language='html'
    light
    format={true}
    code={`
<ux-form async>
    <form action="./mock-data/whitepaper/whitepaper-step-2.html" method="POST">
        <div class="row">
            <!-- ELEMENT1 -->
            <div class="gr-8@large push-2@large gr-10@d push-1@d gr-12 no-gutter">
                <ux-form-group data-validation-group--min="1"
                    data-validation-group--msg="Select at least one whitepaper"
                    manage-all-checkboxes="Select all"
                    manage-all-wrapper-class="ux-u-margin-horizontal-15 ux-u-margin-bottom-25"
                >
                    <div class="row">
                        <div class="gr-12">
                            <div class="ux-u-border-bottom"></div>
                        </div>
                        <!-- ELEMENT2 -->
                        <div class="gr-12 no-gutter">
                            <!-- loop over the download teasers here -->
                            <div class="gr-12">
                                <ux-iws-teaser-selectable-download>
                                    <!-- content of the download teaser -->
                                </ux-iws-teaser-selectable-download>
                            </div>
                        </div>
                    </div>
                </ux-form-group>
            </div>
            <div class="gr-12">
                <div class="ux-u-margin-top-30 ux-u-text-align--center">
                    <button type="submit"
                        class="ux-button ux-button--green ux-u-margin-vertical-10">
                        Download
                    </button>
                </div>
            </div>
        </div>
    </form>
</ux-form>
    `}
>
</Source>

# HTML For Second Step of the Form

This is the form HTML code that needs to be sent for the second part of the form. <br />
The classes of the elements are different based on these settings: if a marginal column is
present and if the one column layout or two column layout is selected. <br />
Look at the comments in the HTML code that are above the element with changing classes
depending on the above mentioned variables. The different classes for these elements Depending
on the configuration are described in the following table:

<table style={{ width: "100%" }}>
    <thead>
        <tr>
            <th></th>
            <th>one column - no sidebar</th>
            <th>one column - with sidebar</th>
            <th>two columns - no sidebar</th>
            <th>two columns - with sidebar</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td class="ux-u-text-bold">ELEMENT1</td>
            <td>gr-6@large push-3@large gr-10@d push-1@d</td>
            <td>gr-8@large push-2@large gr-10@d push-1@d</td>
            <td>gr-8@large push-2@large gr-12@d push-0@d</td>
            <td>gr-12@large push-0@large gr-12@d push-0@d</td>
        </tr>
        <tr>
            <td class="ux-u-text-bold">ELEMENT2</td>
            <td>gr-12@t gr-12@m gr-12 ux-u-margin-bottom-25</td>
            <td>gr-12@t gr-12@m gr-12 ux-u-margin-bottom-25</td>
            <td>gr-12@t gr-12@m gr-6 ux-u-margin-bottom-25</td>
            <td>gr-12@t gr-12@m gr-6 ux-u-margin-bottom-25</td>
        </tr>
    </tbody>
</table>

<Source 
    language='html'
    light
    format={true}
    code={`
<form action="./mock-data/whitepaper/whitepaper-success.html">
    <div class="row">
        <!-- ELEMENT 1 -->
        <div class="gr-6@large push-3@large gr-10@d push-1@d gr-12 no-gutter@m">
            <div class="row">
                <!-- Start of the form elements: one after the other, with ELEMENT 2 as wrapper -->
                <!-- ELEMENT 2 -->
                <div class="gr-12@t gr-12@m gr-12 ux-u-margin-bottom-25">
                    <ux-input-field label="insert all the necessary form elements" required>
                    </ux-input-field>
                </div>
                <!-- End of the form elements -->
                <div class="gr-12 ux-u-margin-bottom-25">
                    <div class="ux-text-normal ux-text-normal--light-gray">
                        * Pflichtfelder sind mit einem * gekennzeichnet.
                    </div>
                </div>
            </div>
            <div class="row">
                <div class="gr-12 ux-u-text-align--center ux-u-margin-top-10">
                    <div class="ux-button-group ux-button-group--with-spacing">
                        <button 
                            type="button" 
                            formnovalidate 
                            formaction="./mock-data/whitepaper/whitepaper-step-1.html" 
                            class="ux-button ux-u-margin-bottom-15"
                        >
                            Previous
                        </button>
                        <button type="submit" href="#"
                            class="ux-button ux-button--green ux-u-margin-bottom-15">
                            Download
                        </button>
                    </div>
                </div>
            </div>
        </div>
    </div>
</form>
    `}
>
</Source>

# HTML For Success Message of the Form

Insert appropriate text for the title and the body text where the comments are.

<Source
    language="html"
    light
    format={true}
    code={`
<div class="row">
    <div class="gr-12 no-gutter ux-u-margin-bottom-40">
        <div class="row">
            <div class="gr-12 u-hide@t u-hide@d u-hide@large ux-u-text-align--center">
                <ux-icon name="checkmark" class="ux-color-success" size-s="45"></ux-icon>
            </div>
            <div class="gr-12 ux-u-center-content ux-u-text-align--center">
                <ux-icon name="checkmark" class="ux-color-success u-hide@m ux-u-margin-right-15 ux-u-margin-bottom-10"
                    size-s="50"></ux-icon>
                <span class="ux-text-headline ux-text-headline--medium">
                    insert the title of the message
                </span>
            </div>
            <div class="gr-12 ux-u-text-align--center">
                <div class="ux-text-normal ux-text-normal--light-gray">
                    Insert the body of the message here
                </div>
            </div>
        </div>
    </div>
</div>
    `}
></Source>
